/*******************************************************************************
 * Copyright 2011 @ Kapil Viren Ahuja
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package com.kapil.framework.crypto;

import org.apache.commons.codec.binary.Base64;

import com.kapil.framework.lang.StringUtils;


/**
 * Provides utility methods for conversion from and to <code>Base-64</code> encoding.
 */
public final class Base64Util
{
    private static final Base64 DECODER = new Base64();

    private static final Base64 ENCODER = new Base64();

    private Base64Util()
    {
    }


    /**
     * Decodes a string potentially containing Base-64 characters.
     *
     * @param input A {@link java.lang.String} to be decoded.
     * @return An array of bytes containing the decoded string.
     */
    public static byte[] decode(String input)
    {
        byte[] output = null;

        if (StringUtils.isNotBlank(input))
        {
                output = DECODER.decode(input);
        }

        return output;
    }

    /**
     * Encodes an array of bytes using Base-64 encoding.
     *
     * @param input An array of bytes to be encoded.
     * @return A {@link java.lang.String} containing encoded output.
     */
    public static String encode(byte[] input)
    {
        return input == null ? null : ENCODER.encodeToString(input);
    }
}
