/*******************************************************************************
 * Copyright 2011 @ Kapil Viren Ahuja
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package com.kapil.framework.crypto;

/**
 * Factory implementation to create instaces of {@link IDigester}
 */
public final class ObfuscationFactory
{
    private static final ObfuscationFactory INSTANCE = new ObfuscationFactory();

    /**
     * Made private to enforce <code>Singleton</code>pattern.
     */
    private ObfuscationFactory()
    {
    }

    /**
     * Returns the singleton instance of the class.
     *
     * @return An {@link ObfuscationFactory} object.
     */
    public static ObfuscationFactory getInstance()
    {
        return INSTANCE;
    }

    /**
     * Creates an object capable of generating secure message digest (one-way hash).
     *
     * @return A {@link IDigester} object.
     */
    public IDigester getSecureDigester()
    {
        return new SaltedSecureHashDigester();
    }

    /**
     * Creates an object capable of generating simple message digest (one-way hash).
     *
     * @return A {@link IDigester} object.
     */
    public IDigester getSimpleDigester()
    {
        return new SecureHashDigester();
    }
}
