/*******************************************************************************
 * Copyright 2011 @ Kapil Viren Ahuja
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package com.kapil.framework.exception;


/**
 * <p>
 * Base for all business exception classes in the application. It enforces all business exception classes to provide
 * contextual runtime information while raising exceptions. This is important to facilitate debugging by including
 * appropriate information in error messages written to application logs as well as those shown on the front-end.
 * </p>
 * 
 */
public abstract class BusinessException extends BaseException
{
    private static final long serialVersionUID = -6165099358214288039L;


    /**
     * @see BaseException#BaseException(String, Throwable)
     */
    protected BusinessException(final String errorCode, final Throwable linkedException)
    {
        super(errorCode, linkedException);
    }

    /**
     * @see BaseException#BaseException(String, String[], Throwable)
     */
    protected BusinessException(final String errorCode, final String[] errorMessageTokens, final Throwable linkedException)
    {
        super(errorCode, errorMessageTokens, linkedException);
    }

    /**
     * @see BaseException#BaseException(String, String[])
     */
    protected BusinessException(final String errorCode, final String[] tokens)
    {
        super(errorCode, tokens);
    }


    /**
     * @see BaseException#BaseException(String)
     */
    protected BusinessException(final String errorCode)
    {
        super(errorCode);
    }
}
