/*******************************************************************************
 * Copyright 2011 @ Kapil Viren Ahuja
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package com.kapil.framework.logger;

/**
 * <p>
 * Factory used to create instances of {@link ILogger}.
 * </p>
 */
@SuppressWarnings("rawtypes")
public final class LogFactory
{
    
    /** LOCAL_INSTANCE - static instance of the class. */
    private static final LogFactory LOCAL_INSTANCE = new LogFactory();

    /**
     * Default constructor. Made private to enforce Singleton pattern.
     * 
     */
    private LogFactory()
    {
    }

    
    /**
     * Gets the single instance of LogFactory.
     * 
     * @return An instance of {@link LogFactory}
     */
    public static LogFactory getInstance()
    {
        return LOCAL_INSTANCE;
    }

    /**
     * Returns a {@link ILogger} instance suitable for logging.
     * 
     * @param clazz object of {@link Class} for which the logger needs to be instantiated.
     * 
     * @return A {@link ILogger} instance holding {@link DefaultLogger} implementation
     */
    public ILogger getLogger(Class clazz)
    {
        return new DefaultLogger(clazz);
    }

    /**
     * Returns a {@link ILogger} instance suitable for logging.
     * 
     * @param logger object of {@link String} for which the logger needs to be instantiated.
     * 
     * @return A {@link ILogger} instance holding {@link DefaultLogger} implementation
     */
    public ILogger getLogger(String logger)
    {
        return new DefaultLogger(logger);
    }
}
